@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# SPDX-FileCopyrightText: 2021-2023 Greenbone AG
+# SPDX-FileCopyrightText: 2021-2024 Greenbone AG
 #
 # SPDX-License-Identifier: AGPL-3.0-or-later
 import hashlib
@@ -104,7 +103,7 @@ def gpg_sha256sums(
         if not verified:
             return None
         result = {}
-        with hash_file.open() as f:
+        with hash_file.open() as f:  # noqa: PLW2901
             for line in f.readlines():
                 hsum, fname = line.split("  ")
                 # the second part can contain a newline
