@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# SPDX-FileCopyrightText: 2021-2023 Greenbone AG
+# SPDX-FileCopyrightText: 2021-2024 Greenbone AG
 #
 # SPDX-License-Identifier: AGPL-3.0-or-later
 
@@ -75,9 +74,9 @@ class Message:
     def serialize(self) -> Dict[str, Union[int, str]]:
         return {
             "message_id": str(self.message_id),
-            "message_type": self.message_type.value
-            if self.message_type
-            else None,
+            "message_type": (
+                self.message_type.value if self.message_type else None
+            ),
             "group_id": str(self.group_id),
             "created": self.created.timestamp(),
         }
